@@ -1,13 +1,12 @@
-# -*- coding: utf-8 -*-
+### -*- coding: utf-8 -*- #############################################
+#######################################################################
 """The object event channel
 
-$Id: objecteventchannel.py 457 2007-01-19 03:55:29Z cray $
+$Id: objecteventchannel.py 51890 2008-10-21 08:05:28Z cray $
 """
 __author__  = "Andrey Orlov 2006 12 05"
 __license__ = "GPL"
-__version__ = "$Revision: 457 $"
-__date__ = "$Date: 2007-01-19 06:55:29 +0300 (Птн, 19 Янв 2007) $"
-__credits__ = """Andrey Orlov, for idea and common control"""
+__version__ = "$Revision: 51890 $"
 
 from zope.interface import implements
 from zope.event import subscribers
@@ -17,4 +16,5 @@ def objectEventChannel(event) :
     #notify is misdeclared as one-argument function and we are to use
     #its content to call all dispatcher 
     for dispatch in subscribers :
-        dispatch(event.object,event)
\ No newline at end of file
+        dispatch(event.object,event)
+        
\ No newline at end of file
